import setuptools
import setuptools
import platform

nvidia_libraries = [
    "chromadb",
    "chroma-hnswlib",
    "llama-index",
    "llama-index-agent-openai",
    "llama-index-cli",
    "llama-index-core",
    "llama-index-embeddings-openai",
    "llama-index-indices-managed-llama-cloud",
    "llama-index-legacy",
    "llama-index-llms-openai",
    "llama-index-multi-modal-llms-openai",
    "llama-index-program-openai",
    "llama-index-question-gen-openai",
    "llama-index-readers-file",
    "llama-index-readers-llama-parse",
    "llama-index-vector-stores-chroma",
    "llama-parse",
    "llamaindex-py-client",
    "nvidia-cublas-cu12",
    "nvidia-cuda-cupti-cu12",
    "nvidia-cuda-nvrtc-cu12",
    "nvidia-cuda-runtime-cu12",
    "nvidia-cudnn-cu12",
    "nvidia-cufft-cu12",
    "nvidia-curand-cu12",
    "nvidia-cusolver-cu12",
    "nvidia-cusparse-cu12",
    "nvidia-nccl-cu12",
    "nvidia-nvjitlink-cu12",
    "nvidia-nvtx-cu12",
    "grpcio",
    'triton',
]

if platform.system() == "Linux" and "NVIDIA" in platform.uname().release:
    install_requires = setuptools.find_packages() + nvidia_libraries
else:
    install_requires = setuptools.find_packages()

setuptools.setup(
    name="hammadml",
    version="0.0.18",
    author="Hammad Saeed",
    author_email="hammad@supportvectors.com",
    description="Hammad Python  ~ Machine Learning",
    long_description="""
Hammad's Python -- ML Tools

Documentation available at: https://github.com/hsaeed3/hammad-machine-learning
    """,
    packages=install_requires,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>3.10',
    install_requires=[
        "aiohttp",
        "aiosignal",
        "annotated-types",
        "annoy",
        "anyio",
        "argcomplete",
        "asgiref",
        "asttokens",
        "async-timeout",
        "attrs",
        "backcall",
        "backoff",
        "bcrypt",
        "beautifulsoup4",
        "bleach",
        "blis",
        "Bottleneck",
        "bs4",
        "build",
        "cachetools",
        "catalogue",
        "certifi",
        "charset-normalizer",
        "click",
        "cloudpathlib",
        "colorama",
        "coloredlogs",
        "confection",
        "cymem",
        "dataclasses-json",
        "decorator",
        "defusedxml",
        "Deprecated",
        "dirtyjson",
        "distro",
        "docopt",
        "docstring-parser",
        "exceptiongroup",
        "executing",
        "fastapi",
        "fastjsonschema",
        "filelock",
        "flatbuffers",
        "frozenlist",
        "fsspec",
        "google-auth",
        "googleapis-common-protos",
        "greenlet",
        "h11",
        "hammadpy",
        "httpcore",
        "httptools",
        "httpx",
        "huggingface-hub",
        "humanfriendly",
        "idna",
        "importlib-metadata",
        "importlib_resources",
        "instructor",
        "ipython",
        "jedi",
        "Jinja2",
        "joblib",
        "jsonpatch",
        "jsonpointer",
        "jsonschema",
        "jsonschema-specifications",
        "jupyter_client",
        "jupyter_core",
        "jupyterlab_pygments",
        "kubernetes",
        "langchain",
        "langchain-community",
        "langchain-core",
        "langcodes",
        "langsmith",
        "markdown-it-py",
        "MarkupSafe",
        "marshmallow",
        "matplotlib-inline",
        "mdurl",
        "mistune",
        "mmh3",
        "monotonic",
        "mpmath",
        "multidict",
        "murmurhash",
        "mypy-extensions",
        "nbclient",
        "nbconvert",
        "nbformat",
        "nest-asyncio",
        "networkx",
        "nltk",
        "numpy",
        "oauthlib",
        "onnxruntime",
        "openai",
        "opentelemetry-api",
        "opentelemetry-exporter-otlp-proto-common",
        "opentelemetry-exporter-otlp-proto-grpc",
        "opentelemetry-instrumentation",
        "opentelemetry-instrumentation-asgi",
        "opentelemetry-instrumentation-fastapi",
        "opentelemetry-proto",
        "opentelemetry-sdk",
        "opentelemetry-semantic-conventions",
        "opentelemetry-util-http",
        "orjson",
        "overrides",
        "packaging",
        "pandas",
        "pandocfilters",
        "parso",
        "pexpect",
        "pickleshare",
        "pillow",
        "pipreqs",
        "platformdirs",
        "posthog",
        "preshed",
        "prompt-toolkit",
        "protobuf",
        "ptyprocess",
        "pulsar-client",
        "pure-eval",
        "pyasn1",
        "pyasn1-modules",
        "pydantic",
        "pydantic_core",
        "Pygments",
        "PyMuPDF",
        "PyMuPDFb",
        "pypdf",
        "PyPika",
        "pyproject_hooks",
        "python-dateutil",
        "python-dotenv",
        "pytz",
        "PyYAML",
        "pyzmq",
        "referencing",
        "regex",
        "requests",
        "requests-oauthlib",
        "rich",
        "rpds-py",
        "rsa",
        "safetensors",
        "scikit-learn",
        "scipy",
        "sentence-transformers",
        "six",
        "smart-open",
        "sniffio",
        "soupsieve",
        "spacy",
        "spacy-legacy",
        "spacy-loggers",
        "SQLAlchemy",
        "srsly",
        "stack-data",
        "starlette",
        "sympy",
        "tenacity",
        "thinc",
        "threadpoolctl",
        "tiktoken",
        "tinycss2",
        "tokenizers",
        "tomli",
        "torch",
        "tornado",
        "tqdm",
        "traitlets",
        "transformers",
        "typer",
        "typing-inspect",
        "typing_extensions",
        "tzdata",
        "urllib3",
        "uvicorn",
        "uvloop",
        "wasabi",
        "watchfiles",
        "wcwidth",
        "weasel",
        "webencodings",
        "websocket-client",
        "websockets",
        "Whoosh",
        "wrapt",
        "yarg",
        "yarl",
        "zipp"
    ]
)